@@ -1,3 +1,4 @@
+mod array;
 mod bool;
 mod btreemap;
 #[cfg(feature = "chrono")]
@@ -6,5 +7,6 @@ mod floats;
 mod hashmap;
 mod integers;
 mod optional;
+mod slice;
 mod string;
 mod vec;
